import { select, 
        json,
        csv,
        tsv, 
        geoPath,
        geoMercator,
        scaleOrdinal,
        schemeCategory10,
        zoom,
        event } from 'd3';
import { feature } from 'topojson';

//selecting the svg area where chart will be plotted
const svg = select('svg');
const width = parseFloat(svg.attr('width'));
const height = +svg.attr('height');
let stateNames = [];

//defining the charts projection with d3.js geoMercator() function
const projection = geoMercator()
			.clipExtent([[0,0],[width,height]])
			.center([85, 24.6])
			.scale(770);

//defining the path with d3.js geoPath() function
const pathGenerator = geoPath()
		.projection(projection);

const g = svg.append('g');

// rendering topographic layer of the map
svg.call(zoom().on('zoom', () => {
	g.attr('transform', event.transform)
}));

//
//loading data
json('https://raw.githubusercontent.com/greencoder/geobatch/master/brazil.geojson')
  .then((data) => {
  //extracting states data
  const countryShapes = feature(
    data,
    data.objects.IND_adm1
  );
             json('https://raw.githubusercontent.com/greencoder/geobatch/master/brazil.geojson')
            ]).then(([stateJSON, districtJSON]) => {
	 
  const districtGroup = g.append('g')
  const stateGroup = g.append('g');
  
  const districts = feature(districtJSON, districtJSON.objects['india-districts-2019-734']);			
  const states = feature(stateJSON, stateJSON.objects.IND_adm1);
  
  const colorScale = scaleOrdinal(schemeCategory10);
  
  const districtPath = districtGroup.selectAll('path')
    .data(districts.features)
  districtPath.enter().append('path')
    .attr("class", "districts")
    .attr('d', d => pathGenerator(d))
  	.style('fill', d => colorScale(d.properties.st_nm))
  .append('title')
    .text(d => {
    return `${d.properties.district}, \n${d.properties.st_nm}`;
  	});
  
  const statePath = stateGroup.selectAll('path')
    .data(states.features)
  statePath.enter().append('path')
    .attr('class', 'states')
    .attr('d', d => pathGenerator(d))
  .style('title')
  .text(d => {
    return `${d.properties.state}, \n${d.properties.st_nm}`;
  	});
});
      
//Rendering text with states names in the middle of the state
svg
  .selectAll('text')
  .data(statepath.features)
  .enter
   .append('text')
   .text((d) => d.properties.states)
   .attr('x', d=>  pathGenerator(d)   )
    .attr('y',d=>pathGenerator.centroid(d))
    .attr("text-anchor", "middle")
    .attr("font-size", "8px");
});
